var topics =
[
    [ "Boost libraries.", "group__BOOST.html", "group__BOOST" ],
    [ "Libsolv interface", "group__LIBSOLV.html", null ],
    [ "Libzypp History File", "group__g__ZyppHistory.html", "group__g__ZyppHistory" ],
    [ "Enumeration Class", "group__g__EnumerationClass.html", "group__g__EnumerationClass" ],
    [ "RAII solutions", "group__g__RAII.html", "group__g__RAII" ],
    [ "CRTP solutions", "group__g__CRTP.html", "group__g__CRTP" ],
    [ "Backend Specific", "group__g__BackenSpecific.html", null ],
    [ "Filters and Functors", "group__g__Functor.html", "group__g__Functor" ],
    [ "Algorithms", "group__g__Algorithm.html", null ],
    [ "Parser", "group__g__Parser.html", null ],
    [ "Debug tools", "group__DEBUG.html", "group__DEBUG" ],
    [ "Comparison using relational operator zypp::Rel.", "group__RelCompare.html", "group__RelCompare" ],
    [ "ZYPP_RESOLVABLE_SMART_POINTER_TYPES", "group__ZYPP__RESOLVABLE__SMART__POINTER__TYPES.html", null ],
    [ "ZYPP_THROW macros", "group__ZYPP__THROW.html", null ],
    [ "Boost.Iterator Library", "group__ITERATOR.html", null ],
    [ "ZYPP_BASE_LOGGER_MACROS", "group__ZYPP__BASE__LOGGER__MACROS.html", null ],
    [ "Smart pointer types", "group__ZYPP__SMART__PTR.html", "group__ZYPP__SMART__PTR" ],
    [ "Regular expression matching", "group__ZYPP__STR__REGEX.html", "group__ZYPP__STR__REGEX" ],
    [ "Zypp Configuration Options", "group__ZyppConfig.html", "group__ZyppConfig" ]
];